
from distutils.core import setup

setup(
    name = "nester_pro",
    version = "1.0.0",
    py_modules = ["nester"],
    author = "chenbq",
    autor_email = "chenbq@test.com",
    url = "http://www.test.com",
    description = "A simple printer of nested list"
    )
